#ifndef _ASM_XPARAMETERS_H
#define _ASM_XPARAMETERS_H

#ifdef __KERNEL__

#include <linux/config.h>
#include <asm/xparameters_bsp.h>

/* check and generalize components: */
/* RAM */
#if defined XPAR_MPMC_0_MPMC_BASEADDR
	#define RAM_BASEADDR	XPAR_MPMC_0_MPMC_BASEADDR
	#define RAM_HIGHADDR	XPAR_MPMC_0_MPMC_HIGHADDR
	#define RAM_NAME		XPAR_MPMC_0_HW_NAME	
	#define RAM_VER			XPAR_MPMC_0_HW_VER
#elif defined XPAR_DDR_0_MEM0_BASEADDR
	#define RAM_BASEADDR	XPAR_DDR_0_MEM0_BASEADDR
	#define RAM_HIGHADDR	XPAR_DDR_0_MEM0_HIGHADDR
	#define RAM_NAME		XPAR_DDR_0_HW_NAME
	#define RAM_VER			XPAR_DDR_0_HW_VER
#endif
/* try to detect an uncached shadow */
#if XPAR_MICROBLAZE_0_USE_DCACHE
	/* If SDRAM is cached*/
	#if XPAR_MICROBLAZE_0_DCACHE_BASEADDR==RAM_BASEADDR
		/* And if SDRAM size is setup to be twise as large as cached size*/
		#if  (XPAR_MICROBLAZE_0_DCACHE_HIGHADDR - XPAR_MICROBLAZE_0_DCACHE_BASEADDR + 1)==((RAM_HIGHADDR - RAM_BASEADDR + 1) / 2)
			/* The user has setup an uncached SDRAM shadow in the design and we should consider it*/
			#undef	RAM_HIGHADDR
			#define	RAM_HIGHADDR		XPAR_MICROBLAZE_0_DCACHE_HIGHADDR
			#ifdef NO_MM
				#define	has_uncached_shadow
			#else
/*				#error	You don't need an uncached shadow when using MMU ! */
			#endif
		#endif
	#endif
#endif
#define	RAM_SIZE 			(RAM_HIGHADDR - RAM_BASEADDR + 1)

/* Interrupts controller */
#define INTC_BASEADDR	XPAR_INTC_0_BASEADDR
#define INTC_HIGHADDR	XPAR_INTC_0_HIGHADDR	
#define INTC_KIND_OF_INTR	XPAR_INTC_0_KIND_OF_INTR
#define INTC_NAME		XPAR_INTC_0_HW_NAME
#define INTC_VER		XPAR_INTC_0_HW_VER
	
/* System timer*/
#define TIMER_BASEADDR	XPAR_TIMER_0_BASEADDR
#define TIMER_HIGHADDR	XPAR_TIMER_0_HIGHADDR
#define TIMER_IRQ		XPAR_TIMER_0_IRQ
#define TIMER_NAME		XPAR_TIMER_0_HW_NAME
#define TIMER_VER		XPAR_TIMER_0_HW_VER

/* LocalLink TYPE Enumerations */
#define XPAR_LL_FIFO	1
#define XPAR_LL_DMA	2

/* SPI */
#ifdef XPS_SPI_1_00_A /* this version doesn't have such parameters*/
	#define XPAR_SPI_0_SPI_SLAVE_ONLY	0
	#define XPAR_SPI_0_DEV_BLK_ID		0
#endif

#if defined(XPAR_SPI_0_BASEADDR) && !defined(XPAR_SPI_0_IRQ)
#ifdef CONFIG_XILINX_SPI
#error XILINX SPI driver does not support polled mode. Connect the interrupt pin to IntC.
#else
#define XPAR_SPI_0_IRQ 0
#endif
#endif /* XPAR_SPI_0_BASEADDR && !XPAR_SPI_0_IRQ */

/* EMAC */
#if defined(XPAR_EMAC_0_BASEADDR) && !defined(XPAR_EMAC_0_IRQ)
#ifdef CONFIG_XILINX_EMAC
#error XILINX EMAC driver does not support polled mode. Connect the interrupt pin to IntC.
#else
#define XPAR_EMAC_0_IRQ 0
#endif
#endif /* XPAR_EMAC_0_BASEADDR && !XPAR_EMAC_0_IRQ */

#if defined(XPAR_EMAC_1_BASEADDR) && !defined(XPAR_EMAC_1_IRQ)
#ifdef CONFIG_XILINX_EMAC
#error XILINX EMAC driver does not support polled mode. Connect the interrupt pin to IntC.
#else
#define XPAR_EMAC_1_IRQ 0
#endif
#endif /* XPAR_EMAC_1_BASEADDR && !XPAR_EMAC_1_IRQ */

/* TEMAC */
#if defined(XPAR_TEMAC_0_BASEADDR) && !defined(XPAR_TEMAC_0_IRQ)
#ifdef CONFIG_XILINX_TEMAC
#error XILINX TEMAC driver does not support polled mode. Connect the interrupt pin to IntC.
#else
#define XPAR_TEMAC_0_IRQ 0
#endif
#endif /* XPAR_TEMAC_0_BASEADDR && !XPAR_TEMAC_0_IRQ */

#if defined(XPAR_TEMAC_1_BASEADDR) && !defined(XPAR_TEMAC_1_IRQ)
#ifdef CONFIG_XILINX_TEMAC
#error XILINX TEMAC driver does not support polled mode. Connect the interrupt pin to IntC.
#else
#define XPAR_TEMAC_1_IRQ 0
#endif
#endif /* XPAR_TEMAC_1_BASEADDR && !XPAR_TEMAC_1_IRQ */

/* IIC */
#if defined(XPAR_IIC_0_BASEADDR) && !defined(XPAR_IIC_0_IRQ)
#ifdef CONFIG_XILINX_IIC
#error XILINX IIC driver does not support polled mode. Connect the interrupt pin to IntC.
#else
#define XPAR_IIC_0_IRQ 0
#endif
#endif /* XPAR_IIC_0_BASEADDR && !XPAR_IIC_0_IRQ */

/* LL_TEMAC */
#if defined(XPAR_LL_TEMAC_0_BASEADDR) && !defined(XPAR_LL_TEMAC_0_IRQ)
#ifdef CONFIG_XILINX_LL_TEMAC
#error XILINX LL_TEMAC driver does not support polled mode. Connect the interrupt pin to IntC.
#else
#define XPAR_LL_TEMAC_0_IRQ 0
#define XPAR_LLTEMAC_0_LLINK_CONNECTED_DMARX_INTR 0
#define XPAR_LLTEMAC_0_LLINK_CONNECTED_DMATX_INTR 0
#define XPAR_LLTEMAC_0_LLINK_CONNECTED_FIFO_INTR 0
#endif
#endif /* XPAR_TEMAC_0_BASEADDR && !XPAR_LL_TEMAC_0_IRQ */

#if defined(XPAR_LL_TEMAC_1_BASEADDR) && !defined(XPAR_LL_TEMAC_1_IRQ)
#ifdef CONFIG_XILINX_LL_TEMAC
#error XILINX LL_TEMAC driver does not support polled mode. Connect the interrupt pin to IntC.
#else
#define XPAR_LL_TEMAC_1_IRQ 0
#define XPAR_LLTEMAC_1_LLINK_CONNECTED_DMARX_INTR 0
#define XPAR_LLTEMAC_1_LLINK_CONNECTED_DMATX_INTR 0
#define XPAR_LLTEMAC_1_LLINK_CONNECTED_FIFO_INTR 0
#endif
#endif /* XPAR_TEMAC_1_BASEADDR && !XPAR_LL_TEMAC_1_IRQ */

#endif /* __KERNEL__ */

#endif /* _ASM_XPARAMETERS_H */
